package net.wanji.opt.controller;

import cn.hutool.core.date.DateUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.enums.TurnConvertEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.bo.CrossIdBO;
import net.wanji.databus.vo.GreenwaveListVO;
import net.wanji.opt.bo.*;
import net.wanji.opt.dto.trend.AbnormalCrossListDTO;
import net.wanji.opt.dto.trend.EventAlarmDTO;
import net.wanji.opt.dto.trend.GreenwaveListDTO;
import net.wanji.opt.po.trend.AnalysisRidTurnIndicators;
import net.wanji.opt.po.trend.HoloEventInfoPO;
import net.wanji.opt.service.impl.TrendServiceImpl;
import net.wanji.opt.vo.*;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.ws.rs.core.MediaType;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * 态势监测
 *
 * @author Kent HAN
 */
@Api(value = "TrendController", description = "态势监测")
@RequestMapping("/trend")
@RestController
public class TrendController {
    @Value("${mock.flag:false}")
    private boolean isMock = false;
    private final TrendServiceImpl trendService;

    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    public TrendController(TrendServiceImpl trendService) {
        this.trendService = trendService;
    }

    @ApiOperation(value = "子区信息-路口监测", notes = "子区信息-路口监测", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/greenwaveCrossMonitor",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenWaveCrossMonitorVO.class),
    })
    public JsonViewObject greenwaveCrossMonitor(@RequestBody GreenwaveIdBO greenwaveIdBO) {
        List<GreenWaveCrossMonitorVO> res = trendService.greenwaveCrossMonitor(greenwaveIdBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "子区信息-运行监测", notes = "子区信息-运行监测", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/greenwaveRunMonitor",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveRunMonitorVO.class),
    })
    public JsonViewObject greenwaveRunMonitor(@RequestBody GreenwaveIdBO greenwaveIdBO) {
        List<GreenwaveRunMonitorVO> res = trendService.greenwaveRunMonitor(greenwaveIdBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "干线方案详情", notes = "干线方案详情", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/greenwaveDetail",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveDetailVO.class),
    })
    public JsonViewObject greenwaveDetail(@RequestBody GreenwaveDetailBO bo) throws Exception {
        GreenwaveDetailVO res = trendService.greenwaveDetail(bo);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "干线当前详情", notes = "干线当前详情", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/currentGreenwaveDetail",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveDetailVO.class),
    })
    public JsonViewObject currentGreenwaveDetail(@RequestBody GreenwaveIdBO bo) throws Exception {
        GreenwaveDetailVO res = trendService.currentGreenwaveDetail(bo);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "保存子区策略", notes = "保存子区策略", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/saveGreenwaveStrategy",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = JsonViewObject.class),
    })
    public JsonViewObject saveGreenwaveStrategy(@RequestBody SaveGreenwaveStrategyBO saveGreenwaveStrategyBO) {
        trendService.saveGreenwaveStrategy(saveGreenwaveStrategyBO);
        return JsonViewObject.newInstance().success();
    }

    @ApiOperation(value = "子区路口指标", notes = "子区路口指标", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/greenwaveCrossMetrics",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveCrossMetricsVO.class),
    })
    public JsonViewObject greenwaveCrossMetrics(@RequestBody GreenwaveIdAndTimeStampBO greenwaveIdAndTimeStampBO) throws Exception {
        List<GreenwaveCrossMetricsVO> res = trendService.greenwaveCrossMetrics(greenwaveIdAndTimeStampBO);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "问题子区列表", notes = "问题子区列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/greenwaveList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenwaveVO.class),
    })
    public JsonViewObject greenwaveList(@RequestBody GreenwaveListDTO greenwaveListDTO) {
        GreenwaveVO greenwaveVO = new GreenwaveVO();
        List<GreenwaveListVO> greenwaveListVOList = trendService.greenwaveList(greenwaveListDTO);
        greenwaveVO.setGreenwaveList(greenwaveListVOList);
        // 绿波统计信息
        GreenwaveListDTO forStats = new GreenwaveListDTO();
        List<GreenwaveListVO> greenwaveListForStats = trendService.greenwaveList(forStats);
        GreenwaveStats greenwaveStats = trendService.buildGreenwaveStats(greenwaveListForStats);
        greenwaveVO.setGreenwaveStats(greenwaveStats);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(greenwaveVO);
    }

    @ApiOperation(value = "问题路口列表", notes = "问题路口列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/abnormalCrossList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AbnormalCrossVO.class),
    })
    public JsonViewObject abnormalCrossList(@RequestBody AbnormalCrossListDTO abnormalCrossListDTO) {
        AbnormalCrossVO abnormalCrossVO = trendService.abnormalCrossList(abnormalCrossListDTO);
        return JsonViewObject.newInstance().success(abnormalCrossVO);
    }

    @ApiOperation(value = "问题路口详情", notes = "问题路口详情", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/abnormalCrossDetail",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AbnormalCrossDetailVO.class),
    })
    public JsonViewObject abnormalCrossDetail(@RequestBody CrossIdBO crossIdBO) {
        AbnormalCrossDetailVO abnormalCrossDetailVO = trendService.abnormalCrossDetail(crossIdBO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(abnormalCrossDetailVO);
    }

    @ApiOperation(value = "事件告警", notes = "事件告警", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/eventAlarm",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject eventAlarm(@RequestBody EventAlarmDTO eventAlarmDTO) throws ParseException {
        String currentTimeStr = eventAlarmDTO.getCurrentTime();
        Date todayTime = sdf.parse(currentTimeStr);
        List<EventAlarmVO> eventAlarmVOList = trendService.eventAlarm(todayTime);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(eventAlarmVOList);
    }

    @ApiOperation(value = "数量实时推送", notes = "数量实时推送", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/countRealTime",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CountRealTimeVO.class),
    })
    public JsonViewObject countRealTime(@RequestBody CrossIdBO crossIdBO) throws Exception {
        String crossId = crossIdBO.getCrossId();
        CountRealTimeVO countRealTimeVO = trendService.countRealTime(crossId);
        return JsonViewObject.newInstance().success(countRealTimeVO);
    }

    @ApiOperation(value = "表格分时段查询", notes = "表格分时段查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/tableQuery",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = TableQueryVO.class),
    })
    public JsonViewObject tableQuery(@RequestBody CrossIdAndTimeSpanBO crossIdAndTimeSpanBO) throws Exception {
        TableQueryVO tableQueryVO = trendService.tableQuery(crossIdAndTimeSpanBO);
        return JsonViewObject.newInstance().success(tableQueryVO);
    }

    @ApiOperation(value = "表格实时推送", notes = "表格实时推送", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/tableRealTime",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = TableQueryVO.class),
    })
    public JsonViewObject tableRealTime(@RequestBody CrossIdAndIsFirstBO crossIdAndIsFirstBO) throws Exception {
        TableQueryVO tableRealTimeVO = trendService.tableRealTime(crossIdAndIsFirstBO);
        return JsonViewObject.newInstance().success(tableRealTimeVO);
    }

    @ApiOperation(value = "优化类型", notes = "优化类型", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/optType",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = OptTypeVO.class),
    })
    public JsonViewObject optType(@RequestBody CrossIdBO crossIdBO) {
        OptTypeVO optTypeVO = trendService.optType(crossIdBO);
        return JsonViewObject.newInstance().success(optTypeVO);
    }

    @ApiOperation(value = "重点路口监测", notes = "重点路口监测", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/hotspotCross",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HotspotCrossVO.class),
    })
    public JsonViewObject hotspotCross(@RequestBody CommonCrossIdVO commonCrossIdVO) throws Exception {
        List<HotspotCrossVO> hotspotCrossVOS = trendService.hotspotCross(commonCrossIdVO);
        return JsonViewObject.newInstance().success(hotspotCrossVOS);
    }

    @ApiOperation(value = "路口转向数据", notes = "路口转向数据", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/crossTurnData",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HotspotCrossTurnVO.class),
    })
    public JsonViewObject crossTurnData(@RequestBody CommonCrossIdVO commonCrossIdVO) throws Exception {
        List<HotspotCrossTurnVO> hotspotCrossVOS = trendService.crossTurnData(commonCrossIdVO);
        return JsonViewObject.newInstance().success(hotspotCrossVOS);
    }

    @ApiOperation(value = "路口车道数据", notes = "路口车道数据", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/crossLaneData",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HotspotCrossLaneVO.class),
    })
    public JsonViewObject crossLaneData(@RequestBody CommonCrossIdVO commonCrossIdVO) throws Exception {
        List<HotspotCrossLaneVO> hotspotCrossVOS = trendService.crossLaneData(commonCrossIdVO);
        return JsonViewObject.newInstance().success(hotspotCrossVOS);
    }

    @ApiOperation(value = "前五交通流量", notes = "前五交通流量", response = Top5IndexVO.class)
    @GetMapping(value = "/top5Flow")
    public JsonViewObject top5Flow() throws Exception {
        List<Top5IndexVO> results = trendService.top5Flow();
        return JsonViewObject.newInstance().success(results);
    }

    @ApiOperation(value = "路口交通状态", notes = "路口交通状态时长比例", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/crossStatusTimeRate",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossStatusTimeRateVO.class),
    })
    public JsonViewObject crossStatusTimeRate(@RequestBody CommonCrossIdVO commonCrossIdVO) throws Exception {
        CrossStatusTimeRateVO crossStatusTimeRateVO = trendService.crossStatusTimeRate(commonCrossIdVO);
        return JsonViewObject.newInstance().success(crossStatusTimeRateVO);
    }

    /**
     * 交通指标 - 车道级数据
     * @param crossIdDateTimeVO
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "车道级交通指标", notes = "车道级交通指标", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/laneTrafficIndex",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = TableQueryVO.CycleDataElement.class),
    })
    public JsonViewObject laneTrafficIndex(@RequestBody LanePeriodVO crossIdDateTimeVO) throws Exception {
        if(isMock == true){
            crossIdDateTimeVO.setStart(DateUtil.parse("2025-04-09 00:00:00", "yyyy-MM-dd HH:mm:ss"));
            crossIdDateTimeVO.setEnd(DateUtil.parse("2025-04-12 00:00:00", "yyyy-MM-dd HH:mm:ss"));
        }
        List<TableQueryVO.CycleDataElement> result = trendService.laneTrafficIndex(crossIdDateTimeVO);
        return JsonViewObject.newInstance().success(result);
    }

    /**
     * 交通指标 - 转向级数据
     * @param lanePeriodTurnVO
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "转向级交通指标", notes = "转向级交通指标", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/lanePeriodTurnData",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AnalysisRidTurnIndicators.class),
    })
    public JsonViewObject lanePeriodTurnData(@RequestBody LanePeriodTurnVO lanePeriodTurnVO) throws Exception {
        if(isMock == true){
            lanePeriodTurnVO.setStart(DateUtil.parse("2025-04-09 00:00:00", "yyyy-MM-dd HH:mm:ss"));
            lanePeriodTurnVO.setEnd(DateUtil.parse("2025-04-12 00:00:00", "yyyy-MM-dd HH:mm:ss"));
        }
        String turns = lanePeriodTurnVO.getTurns();
        if (turns != null){
            StringBuilder inDir = new StringBuilder();
            StringBuilder turnType = new StringBuilder();

            String[] turnArr = turns.split(",");
            for (int i =0; i < turnArr.length; i++){
                String[] s = turnArr[i].split("-");
                String t = TurnConvertEnum.getCodeByKey(Integer.parseInt(s[1]));
                if (i < turnArr.length - 1) {
                    inDir.append(s[0]).append(",");
                    turnType.append(t).append(",");
                }else {
                    inDir.append(s[0]);
                    turnType.append(t);
                }
            }
            lanePeriodTurnVO.setInDir(inDir.toString());
            lanePeriodTurnVO.setTurnType(turnType.toString());
        }
        List<CrossingTurnQueryVO.CycleDataElement> result = trendService.lanePeriodTurnData(lanePeriodTurnVO);
        return JsonViewObject.newInstance().success(result);
    }

    /**
     * 交通指标 - 路口方向级
     *
     * 条件：
     * {
     *   "granularity": "5m",
     *   "direction": "1,3,5",
     *   "crossId": "12345",
     *   "start": "2024-05-15 10:00:00",
     *   "end": "2025-05-15 11:00:00"
     * }
     * 表：t_cross_dir_data_hist
     * @param periodDirectionVO
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "方向级交通指标", notes = "方向级交通指标", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/periodDirectionData",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AnalysisRidTurnIndicators.class),
    })
    public JsonViewObject periodDirectionData(@RequestBody PeriodDirectionVO periodDirectionVO) throws Exception {
        if(isMock == true){
            periodDirectionVO.setStart(DateUtil.parse("2025-04-10 00:00:00", "yyyy-MM-dd HH:mm:ss"));
            periodDirectionVO.setEnd(DateUtil.parse("2025-04-13 00:00:00", "yyyy-MM-dd HH:mm:ss"));
        }
        List<CrossingDirectionQueryVO.CycleDataElement> result = trendService.periodDirectionData(periodDirectionVO);
        return JsonViewObject.newInstance().success(result);
    }

    /**
     * 车道交通指标 - 路口级
     * 条件：
     * {
     *   "granularity": "5m",
     *   "crossId": "12345",
     *   "start": "2024-05-15 10:00:00",
     *   "end": "2025-05-15 11:00:00"
     * }
     * @param periodCrossingVO
     * @return
     * @throws Exception
     */
    @ApiOperation(value = "路口级交通指标", notes = "路口级交通指标", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/periodCrossingData",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AnalysisRidTurnIndicators.class),
    })
    public JsonViewObject periodDirectionData(@RequestBody PeriodCrossingVO periodCrossingVO) throws Exception {
        if(isMock == true){
            periodCrossingVO.setStart(DateUtil.parse("2025-04-09 00:00:00", "yyyy-MM-dd HH:mm:ss"));
            periodCrossingVO.setEnd(DateUtil.parse("2025-04-12 00:00:00", "yyyy-MM-dd HH:mm:ss"));
        }
        List<CrossingQueryVO.CycleDataElement> result = trendService.periodCrossingData(periodCrossingVO);
        return JsonViewObject.newInstance().success(result);
    }


    @ApiOperation(value = "车道快照指标", notes = "车道快照指标", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/laneSnapshotIndex",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = TableQueryVO.RealTimeDataElement.class),
    })
    public JsonViewObject laneSnapshotIndex(@RequestBody LaneSnapshotIndexVO laneSnapshotIndexVO) throws Exception {
        List<TableQueryVO.RealTimeDataElement> result = trendService.laneSnapshotIndex(laneSnapshotIndexVO);
        return JsonViewObject.newInstance().success(result);
    }

    @ApiOperation(value = "溢出事件", notes = "溢出事件", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/overFlowEvent",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = TableQueryVO.RealTimeDataElement.class),
    })
    public JsonViewObject overFlowEvent(@RequestBody LaneSnapshotIndexVO laneSnapshotIndexVO) throws Exception {
        List<OverflowEvent> result = trendService.overFlowEvent(laneSnapshotIndexVO);
        return JsonViewObject.newInstance().success(result);
    }



    @ApiOperation(value = "事件查询列表", notes = "事件查询列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/holoEventList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HoloEventInfoPO.class),
    })
    public JsonViewObject holoEvenList(@RequestBody HoloEventVO holoEventVO) throws Exception {
        List<HoloEventInfoPO> result = trendService.holoEvenList(holoEventVO);
        return JsonViewObject.newInstance().success(result);
    }

    @ApiOperation(value = "车道查询列表", notes = "车道查询列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/laneIdList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = LaneIdAliasNameVO.class),
    })
    public JsonViewObject laneIdList(@RequestBody CommonCrossIdVO commonCrossIdVO) throws Exception {
        List<LaneIdAliasNameVO> result = trendService.laneIdList(commonCrossIdVO);
        return JsonViewObject.newInstance().success(result);
    }


    /**
     * 周期车道数据导出
     * @param lanePeriodVO
     * @param response
     * @throws Exception
     */
    @ApiOperation(value = "周期车道数据导出功能", notes = "周期导出功能")
    @PostMapping(value = "/periodExcel")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HttpServletResponse.class),
    })
    public void periodLaneExcel(@RequestBody LanePeriodVO lanePeriodVO, HttpServletResponse response) throws Exception {
        trendService.periodLaneExcel(lanePeriodVO, response);
    }

    /**
     * 周期转向数据导出
     * @param periodTurnVO
     * @param response
     * @throws Exception
     */
    @ApiOperation(value = "周期转向数据导出功能", notes = "周期转向数据导出功能")
    @PostMapping(value = "/periodTurnExcel")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HttpServletResponse.class),
    })
    public void periodTurnExcel(@RequestBody LanePeriodTurnVO periodTurnVO, HttpServletResponse response) throws Exception {
        trendService.periodTurnExcel(periodTurnVO, response);
    }

    /**
     * 周期方向数据导出
     * @param directionVO
     * @param response
     * @throws Exception
     */
    @ApiOperation(value = "周期方向数据导出功能", notes = "周期转向数据导出功能")
    @PostMapping(value = "/periodDirExcel")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HttpServletResponse.class),
    })
    public void directionExcel(@RequestBody PeriodDirectionVO directionVO, HttpServletResponse response) throws Exception {
        trendService.periodDirectionExcel(directionVO, response);
    }

    /**
     * 周期路口数据导出
     * @param crossingVO
     * @param response
     * @throws Exception
     */
    @ApiOperation(value = "周期路口数据导出功能", notes = "周期转向数据导出功能")
    @PostMapping(value = "/periodCrossExcel")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HttpServletResponse.class),
    })
    public void crossExcel(@RequestBody PeriodCrossingVO crossingVO, HttpServletResponse response) throws Exception {
        trendService.periodCrossExcel(crossingVO, response);
    }

    @ApiOperation(value = "车道快照数据导出功能", notes = "车道快照数据导出功能")
    @PostMapping(value = "/laneSnapshotExcel")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HttpServletResponse.class),
    })
    public void laneSnapshotExcel(@RequestBody LaneSnapshotIndexVO laneSnapshotIndexVO, HttpServletResponse response) throws Exception {
        trendService.laneSnapshotExcel(laneSnapshotIndexVO, response);
    }

}