package net.wanji.opt.service;

import net.wanji.databus.bo.CrossIdBO;
import net.wanji.databus.vo.GreenwaveListVO;
import net.wanji.opt.bo.*;
import net.wanji.opt.dto.trend.AbnormalCrossListDTO;
import net.wanji.opt.dto.trend.GreenwaveListDTO;
import net.wanji.opt.po.trend.AnalysisRidTurnIndicators;
import net.wanji.opt.po.trend.HoloEventInfoPO;
import net.wanji.opt.vo.*;

import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.util.Date;
import java.util.List;

/**
 * @date 2023/1/12 15:12
 * @desc 态势监测接口服务
 */
public interface TrendService {

    List<GreenwaveListVO> greenwaveList(GreenwaveListDTO greenwaveListDTO);

    GreenwaveStats buildGreenwaveStats(List<GreenwaveListVO> greenwaveListVOList);

    AbnormalCrossVO abnormalCrossList(AbnormalCrossListDTO abnormalCrossListDTO);

    AbnormalCrossDetailVO abnormalCrossDetail(CrossIdBO crossIdBO);

    List<EventAlarmVO> eventAlarm(Date todayTime) throws ParseException;

    List<GreenWaveCrossMonitorVO> greenwaveCrossMonitor(GreenwaveIdBO greenwaveIdBO);

    List<GreenwaveRunMonitorVO> greenwaveRunMonitor(GreenwaveIdBO greenwaveIdBO);

    GreenwaveDetailVO greenwaveDetail(GreenwaveDetailBO greenwaveDetailBO) throws Exception;

    List<GreenwaveCrossMetricsVO> greenwaveCrossMetrics(GreenwaveIdAndTimeStampBO greenwaveIdAndTimeStampBO) throws Exception;

    void saveGreenwaveStrategy(SaveGreenwaveStrategyBO saveGreenwaveStrategyBO);

    GreenwaveDetailVO currentGreenwaveDetail(GreenwaveIdBO bo) throws Exception;

    CountRealTimeVO countRealTime(String crossId) throws Exception;

    TableQueryVO tableQuery(CrossIdAndTimeSpanBO crossIdAndTimeSpanBO) throws Exception;

    TableQueryVO tableRealTime(CrossIdAndIsFirstBO crossIdAndIsFirstBO) throws Exception;

    OptTypeVO optType(CrossIdBO crossIdBO);

    List<HotspotCrossVO> hotspotCross(CommonCrossIdVO commonCrossIdVO) throws Exception;

    List<HotspotCrossTurnVO> crossTurnData(CommonCrossIdVO commonCrossIdVO) throws Exception;

    List<HotspotCrossLaneVO> crossLaneData(CommonCrossIdVO commonCrossIdVO) throws Exception;

    List<Top5IndexVO>  top5Flow() throws Exception;

    CrossStatusTimeRateVO crossStatusTimeRate(CommonCrossIdVO commonCrossIdVO) throws Exception;

    List<TableQueryVO.CycleDataElement> laneTrafficIndex(LanePeriodVO lanePeriodVO) throws Exception;

    List<TableQueryVO.RealTimeDataElement> laneSnapshotIndex(LaneSnapshotIndexVO laneSnapshotIndexVO) throws Exception;
    List<OverflowEvent> overFlowEvent(LaneSnapshotIndexVO laneSnapshotIndexVO) throws Exception;

    List<CrossingTurnQueryVO.CycleDataElement> lanePeriodTurnData(LanePeriodTurnVO lanePeriodTurnVO) throws Exception;

    /**
     * 获取时段方向级数据
     * @param periodDirectionVO
     * @return
     * @throws Exception
     */
    List<CrossingDirectionQueryVO.CycleDataElement> periodDirectionData(PeriodDirectionVO periodDirectionVO) throws Exception;

    /**
     * 获取时段路口级数据
     * @param periodCrossingVO
     * @return
     * @throws Exception
     */
    List<CrossingQueryVO.CycleDataElement> periodCrossingData(PeriodCrossingVO periodCrossingVO) throws Exception;



    List<HoloEventInfoPO> holoEvenList(HoloEventVO holoEventVO) throws Exception;

    List<LaneIdAliasNameVO> laneIdList(CommonCrossIdVO commonCrossIdVO) throws Exception;

//    void periodExcel(CommonCrossIdDateTimeVO crossIdDateTimeVO, HttpServletResponse response) throws Exception;

    void periodTurnExcel(LanePeriodTurnVO lanePeriodTurnVO, HttpServletResponse response) throws Exception;
    /**
     * 周期方向数据导出
     * @param turnVO
     * @param response
     */
    void periodDirectionExcel(PeriodDirectionVO turnVO, HttpServletResponse response);

    /**
     * 周期路口数据导出
     * @param turnVO
     * @param response
     */
    void periodCrossExcel(PeriodCrossingVO turnVO, HttpServletResponse response);
    void laneSnapshotExcel(LaneSnapshotIndexVO laneSnapshotIndexVO, HttpServletResponse response) throws Exception;
}
